@@ -191,10 +191,6 @@ const Application = new Lang.Class({
             if (!success)
                 return;
 
-            // When launching Polari via a URL, there is a potential race
-            // condition between networksManager and AccountsManager here. If
-            // AccountsManager finishes first, networksManager's list of
-            // servers would be empty and hence no matches would be found.
             let matchedId = this._networksManager.findByServer(server);
             let matches = Object.keys(map).filter(function(a) {
                 return GLib.ascii_strcasecmp(map[a].server, server) == 0 ||
@@ -353,7 +349,9 @@ const Application = new Lang.Class({
 
     _updateAccountServer: function(account, server, callback) {
         let sv = { server: GLib.Variant.new('s', server.address),
-                   port: GLib.Variant.new('u', server.port) };
+                   port: GLib.Variant.new('u', server.port),
+                   'use-ssl': GLib.Variant.new('b', server.ssl)
+                    };
         let asv = GLib.Variant.new('a{sv}', sv);
         account.update_parameters_vardict_async(asv, [], callback);
     },
@@ -395,7 +393,7 @@ const Application = new Lang.Class({
           retry: 0,
           originalNick: account.nickname,
           callback: callback,
-          alternateServers: accountServers.filter(s => s != server)
+          alternateServers: accountServers.filter(s => s.address != server)
         };
 
         this._pendingRequests[roomId] = requestData;
