@@ -21,7 +21,13 @@ const NetworksManager = new Lang.Class({
 
         let uri = 'resource:///org/gnome/Polari/data/networks.json';
         let file = Gio.File.new_for_uri(uri);
-        file.load_contents_async(null, Lang.bind(this, this._onContentsReady));
+        let success, data;
+        try {
+            [success, data, ] = file.load_contents(null);
+            this._parseNetworks(data);
+        } catch(e) {
+            log('Failed to load network list: ' + e.message);
+        }
     },
 
     _onContentsReady: function(f, res) {
@@ -32,21 +38,26 @@ const NetworksManager = new Lang.Class({
             log('Failed to load network list: ' + e.message);
             return;
         }
+        if (this._parseNetworks(data))
+            this.emit('changed');
+    },
 
+    _parseNetworks: function(data) {
         let networks;
         try {
             networks = JSON.parse(data);
         } catch(e) {
             log('Failed to parse network list: ' + e.message);
-            return;
+            return false;
         }
 
+        this._networksById.clear();
         this._networks = networks;
         this._networks.forEach(Lang.bind(this,
             function(network) {
                 this._networksById.set(network.id, network);
             }));
-        this.emit('changed');
+        return true;
     },
 
     _lookupNetwork: function(id) {
@@ -68,14 +79,21 @@ const NetworksManager = new Lang.Class({
         return this._lookupNetwork(id).name;
     },
 
+    getNetworkIsFavorite: function(id) {
+        let network = this._lookupNetwork(id);
+
+        if (network.hasOwnProperty('favorite'))
+            return network['favorite'];
+
+        return false;
+    },
+
     getNetworkDetails: function(id) {
         let network = this._lookupNetwork(id);
         if (!network.servers || !network.servers.length)
             throw new Error('No servers for network ' + id);
 
-        let sslServers = network.servers.filter(s => s.ssl);
-        let server = sslServers.length > 0 ? sslServers[0]
-                                           : network.servers[0];
+        let server = this.getNetworkServers(id)[0];
         return {
             'account': new GLib.Variant('s', GLib.get_user_name()),
             'server': new GLib.Variant('s', server.address),
@@ -84,6 +102,13 @@ const NetworksManager = new Lang.Class({
         };
     },
 
+    getNetworkServers: function(id) {
+        let network = this._lookupNetwork(id);
+        let sslServers = network.servers.filter(s => s.ssl);
+        return sslServers.length > 0 ? sslServers
+                                     : network.servers.slice();
+    },
+
     getNetworkMatchTerms: function(id) {
         let network = this._lookupNetwork(id);
         let servers = network.servers.map(function(s) {
